@@ -6,9 +6,13 @@ M2Crypto wrapper for OpenSSL BN (BIGNUM) API.
 Copyright (c) 2005 Open Source Applications Foundation. All rights reserved.
 """
 
-from M2Crypto import m2
+from M2Crypto import m2, util
+if util.py27plus:
+    from typing import Optional  # noqa
+
 
 def rand(bits, top=-1, bottom=0):
+    # type: (int, int, int) -> Optional[int]
     """
     Generate cryptographically strong random number.
 
@@ -22,6 +26,7 @@ def rand(bits, top=-1, bottom=0):
 
 
 def rand_range(range):
+    # type: (int) -> int
     """
     Generate a random number in a range.
 
@@ -32,17 +37,21 @@ def rand_range(range):
 
 
 def randfname(length):
+    # type: (int) -> str
     """
     Return a random filename, which is simply a string where all
     the characters are from the set [a-zA-Z0-9].
 
     @param length: Length of filename to return.
-    @type length:  int
     @return:       random filename string
     """
+    import warnings
+    warnings.warn(
+        "Don't use BN.randfname(), use tempfile methods instead.",
+        DeprecationWarning, stacklevel=2)
     letters = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ01234567890'
     lettersLen = len(letters)
-    fname = []
+    fname = []  # type: list
     for x in range(length):
         fname += [letters[m2.bn_rand_range(lettersLen)]]
 
